From: Nguyen Thai Ngoc Duy Date: Sat, 07 Aug 2010 00:03:40 GMT Subject: Re: [PATCH] pack-object: trim memory usage a tiny bit Message-ID: In-Reply-To: 2010/8/7 Sverre Rabbelier : > Heya, > > 2010/8/6 Nguyễn Thái Ngọc Duy : >> This shrinks struct object_entry from 88 bytes to 80 bytes on my 32 >> bit machine. So that would be 12M less on linux-2.6.git (1.6M objects) >> >> Signed-off-by: Nguyễn Thái Ngọc Duy >> --- >>  Don't know if it's really worth a patch.. > > Either way, some explanation would be nice. struct object_entry is allocated for every object to be packed. So if you do a clone on linux-2.6, you would need 1.6M of those structs, 88 bytes each. I cut 8 bytes from each of them. -- Duy